@@ -1,36 +1,44 @@
-## Copyright (C) 2001 Paul Kienzle
+## Copyright (C) 2001 Paul Kienzle <pkienzle@users.sf.net>
 ##
-## This program is free software; you can redistribute it and/or modify
+## This program is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2 of the License, or
+## the Free Software Foundation, either version 3 of the License, or
 ## (at your option) any later version.
 ##
 ## This program is distributed in the hope that it will be useful,
 ## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 ## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with this program; If not, see <http://www.gnu.org/licenses/>.
+## along with this program; see the file COPYING. If not, see
+## <https://www.gnu.org/licenses/>.
 
-## y = dct (x, n)
-##    Computes the discrete cosine transform of x.  If n is given, then
-##    x is padded or trimmed to length n before computing the transform.
-##    If x is a matrix, compute the transform along the columns of the
-##    the matrix. The transform is faster if x is real-valued and even
-##    length.
+## -*- texinfo -*-
+## @deftypefn  {Function File} {} dct (@var{x})
+## @deftypefnx {Function File} {} dct (@var{x}, @var{n})
+## Compute the discrete cosine transform of @var{x}.  If @var{n} is given,
+## then @var{x} is padded or trimmed to length @var{n} before computing the
+## transform.  If @var{x} is a matrix, compute the transform along the columns
+## of the the matrix.  The transform is faster if @var{x} is real-valued and
+## has even length.
 ##
-## The discrete cosine transform X of x can be defined as follows:
+## The discrete cosine transform @var{x} can be defined as follows:
 ##
+## @example
+## @group
 ##               N-1
 ##   X[k] = w(k) sum x[n] cos (pi (2n+1) k / 2N ),  k = 0, ..., N-1
 ##               n=0
+## @end group
+## @end example
 ##
 ## with w(0) = sqrt(1/N) and w(k) = sqrt(2/N), k = 1, ..., N-1.  There
 ## are other definitions with different scaling of X[k], but this form
 ## is common in image processing.
 ##
-## See also: idct, dct2, idct2, dctmtx
+## @seealso{idct, dct2, idct2, dctmtx}
+## @end deftypefn
 
 ## From Discrete Cosine Transform notes by Brian Evans at UT Austin,
 ## http://www.ece.utexas.edu/~bevans/courses/ee381k/lectures/09_DCT/lecture9/
@@ -54,13 +62,10 @@
 ##
 ## Scaling the result by w(k)/2 will give us the desired output.
 
-## Author: Paul Kienzle
-## 2001-02-08
-##   * initial release
 function y = dct (x, n)
 
   if (nargin < 1 || nargin > 2)
-    usage ("y = dct(x [, n])");
+    print_usage;
   endif
 
   realx = isreal(x);
