@@ -1,17 +1,18 @@
 ## Copyright (C) 2007 Laurent Mazet <mazet@crm.mot.com>
 ##
-## This program is free software; you can redistribute it and/or modify it under
-## the terms of the GNU General Public License as published by the Free Software
-## Foundation; either version 3 of the License, or (at your option) any later
-## version.
+## This program is free software: you can redistribute it and/or modify
+## it under the terms of the GNU General Public License as published by
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
-## This program is distributed in the hope that it will be useful, but WITHOUT
-## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
-## details.
+## This program is distributed in the hope that it will be useful,
+## but WITHOUT ANY WARRANTY; without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+## GNU General Public License for more details.
 ##
-## You should have received a copy of the GNU General Public License along with
-## this program; if not, see <http://www.gnu.org/licenses/>.
+## You should have received a copy of the GNU General Public License
+## along with this program; see the file COPYING. If not, see
+## <https://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn  {Function File} {} tukeywin (@var{m})
@@ -20,8 +21,8 @@
 ## cosine-tapered window) of length @var{m}.  @var{r} defines the ratio
 ## between the constant section and and the cosine section.  It has to be
 ## between 0 and 1.  The function returns a Hanning window for @var{r}
-## equal to 0 and a full box for @var{r} equals to 1.  The default value of
-## @var{r} is 1/2.
+## equal to 1 and a rectangular window for @var{r} equal to 0.
+## The default value of @var{r} is 1/2.
 ##
 ## For a definition of the Tukey window, see e.g. Fredric J. Harris,
 ## "On the Use of Windows for Harmonic Analysis with the Discrete Fourier
